@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -27,7 +27,7 @@ public:
     explicit CodeComment(CodeDocument * doc, const QString & comment = QString());
     virtual ~CodeComment();
 
-    virtual void saveToXMI1(QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
     virtual void loadFromXMI1(QDomElement & root);
 
 protected:
