@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -42,6 +42,7 @@
 #include <QPointer>
 #include <QRegExp>
 #include <QTextStream>
+#include <QXmlStreamWriter>
 
 // system includes
 #include <cstdlib>  // to get the user name
@@ -242,15 +243,16 @@ void CodeGenerator::loadCodeForOperation(const QString& idStr, const QDomElement
 /**
  * Save the XMI representation of this object
  */
-void CodeGenerator::saveToXMI1(QDomDocument & doc, QDomElement & root)
+void CodeGenerator::saveToXMI1(QXmlStreamWriter& writer)
 {
     QString langType = Uml::ProgrammingLanguage::toString(language());
-    QDomElement docElement = doc.createElement(QLatin1String("codegenerator"));
-    docElement.setAttribute(QLatin1String("language"), langType);
+    writer.writeStartElement(QLatin1String("codegenerator"));
+    writer.writeAttribute(QLatin1String("language"), langType);
 
     if (dynamic_cast<SimpleCodeGenerator*>(this)) {
         UMLClassifierList concepts = m_document->classesAndInterfaces();
         foreach (UMLClassifier *c, concepts) {
+            uIgnoreZeroPointer(c);
             UMLOperationList operations = c->getOpList();
             foreach (UMLOperation *op, operations) {
                 // save the source code
@@ -258,10 +260,10 @@ void CodeGenerator::saveToXMI1(QDomDocument & doc, QDomElement & root)
                 if (code.isEmpty()) {
                     continue;
                 }
-                QDomElement codeElement = doc.createElement(QLatin1String("sourcecode"));
-                codeElement.setAttribute(QLatin1String("id"), Uml::ID::toString(op->id()));
-                codeElement.setAttribute(QLatin1String("value"), code);
-                docElement.appendChild(codeElement);
+                writer.writeStartElement(QLatin1String("sourcecode"));
+                writer.writeAttribute(QLatin1String("id"), Uml::ID::toString(op->id()));
+                writer.writeAttribute(QLatin1String("value"), code);
+                writer.writeEndElement();
             }
         }
     }
@@ -270,10 +272,10 @@ void CodeGenerator::saveToXMI1(QDomDocument & doc, QDomElement & root)
         CodeDocumentList::const_iterator it = docList->begin();
         CodeDocumentList::const_iterator end = docList->end();
         for (; it != end; ++it) {
-            (*it)->saveToXMI1(doc, docElement);
+            (*it)->saveToXMI1(writer);
         }
     }
-    root.appendChild(docElement);
+    writer.writeEndElement();
 }
 
 /**
@@ -604,7 +606,7 @@ QString CodeGenerator::findFileName(CodeDocument * codeDocument)
         }
     }
 
-    name.simplified();
+    name = name.simplified();
     name.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
 
     return overwritableName(name, codeDocument->getFileExtension());
