@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -19,6 +19,9 @@
 #include "umldoc.h"
 #include "umlobject.h"
 
+// qt/kde includes
+#include <QXmlStreamWriter>
+
 CodeOperation::CodeOperation (ClassifierCodeDocument * doc, UMLOperation * parentOp, const QString & body, const QString & comment)
         : CodeMethodBlock (doc, parentOp, body, comment)
 {
@@ -69,18 +72,18 @@ UMLOperation * CodeOperation::getParentOperation()
 /**
  * Save the XMI representation of this object.
  */
-void CodeOperation::saveToXMI (QDomDocument & doc, QDomElement & root)
+void CodeOperation::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement blockElement = doc.createElement(QLatin1String("codeoperation"));
+    writer.writeStartElement(QLatin1String("codeoperation"));
     // set attributes
-    setAttributesOnNode(doc, blockElement);
-    root.appendChild(blockElement);
+    setAttributesOnNode(writer);
+    writer.writeEndElement();
 }
 
 /**
  * Load params from the appropriate XMI element node.
  */
-void CodeOperation::loadFromXMI (QDomElement & root)
+void CodeOperation::loadFromXMI1 (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -97,9 +100,9 @@ QString CodeOperation::findTag (UMLOperation * op)
  * Set attributes of the node that represents this class
  * in the XMI document.
  */
-void CodeOperation::setAttributesOnNode (QDomDocument & doc, QDomElement & elem)
+void CodeOperation::setAttributesOnNode (QXmlStreamWriter& writer)
 {
-    CodeMethodBlock::setAttributesOnNode(doc, elem); // superclass
+    CodeMethodBlock::setAttributesOnNode(writer); // superclass
 }
 
 /**
