@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2007 Jari-Matti Mäkelä <jmjm@iki.fi>                    *
- *   copyright (C) 2008-2014                                               *
+ *   copyright (C) 2008-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -41,7 +41,7 @@ public:
     /**
      * Save the XMI representation of this object.
      */
-    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
 
     /**
      * Creates a documentation block.
@@ -55,7 +55,7 @@ public:
 
     /**
      * UnFormat a long text string. Typically, this means removing
-     * the indentaion (linePrefix) and/or newline chars from each line.
+     * the indentation (linePrefix) and/or newline chars from each line.
      */
     virtual QString unformatText (const QString & text, const QString & indent = QString());
 
