@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -23,6 +23,7 @@
 
 // qt includes
 #include <QRegExp>
+#include <QXmlStreamWriter>
 
 JavaANTCodeDocument::JavaANTCodeDocument ()
 {
@@ -76,7 +77,7 @@ void JavaANTCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
 
                 if (name == QLatin1String("codecomment")) {
                     CodeComment * block = new XMLCodeComment(this);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block))
                     {
                         uError()<<"Unable to add codeComment to :"<<this;
@@ -96,7 +97,7 @@ void JavaANTCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                     }
                 } else if (name == QLatin1String("codeblock")) {
                     CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add codeBlock to :"<<this;
                         delete block;
@@ -105,7 +106,7 @@ void JavaANTCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                     }
                 } else if (name == QLatin1String("codeblockwithcomments")) {
                     CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add codeBlockwithcomments to:"<<this;
                         delete block;
@@ -116,7 +117,7 @@ void JavaANTCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                     // do nothing.. this is treated elsewhere
                 } else if (name == QLatin1String("hierarchicalcodeblock")) {
                     HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
                         delete block;
@@ -132,7 +133,7 @@ void JavaANTCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                         CodeOperation * block = 0;
                         uError() << "TODO: implement CodeGenFactory::newCodeOperation() for JavaANTCodeDocument";
                         break;  // remove when above is implemented
-                        block->loadFromXMI(element);
+                        block->loadFromXMI1(element);
                         if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
                         } else {
@@ -145,7 +146,7 @@ void JavaANTCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
                 } else if (name == QLatin1String("xmlelementblock")) {
                     QString xmltag = element.attribute(QLatin1String("nodeName"),QLatin1String("UNKNOWN"));
                     XMLElementCodeBlock * block = new XMLElementCodeBlock(this, xmltag);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add XMLelement to Java ANT document:"<<this;
                         delete block;
@@ -188,7 +189,7 @@ void JavaANTCodeDocument::setAttributesFromNode (QDomElement & root)
 /**
  * load params from the appropriate XMI element node.
  */
-void JavaANTCodeDocument::loadFromXMI (QDomElement & root)
+void JavaANTCodeDocument::loadFromXMI1 (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -196,10 +197,10 @@ void JavaANTCodeDocument::loadFromXMI (QDomElement & root)
 /** set attributes of the node that represents this class
  * in the XMI document.
  */
-void JavaANTCodeDocument::setAttributesOnNode (QDomDocument & doc, QDomElement & docElement)
+void JavaANTCodeDocument::setAttributesOnNode (QXmlStreamWriter& writer)
 {
     // superclass call
-    CodeDocument::setAttributesOnNode(doc, docElement);
+    CodeDocument::setAttributesOnNode(writer);
 
     // now set local attributes/fields
     //FIX
@@ -208,13 +209,13 @@ void JavaANTCodeDocument::setAttributesOnNode (QDomDocument & doc, QDomElement &
 /**
  * Save the XMI representation of this object
  */
-void JavaANTCodeDocument::saveToXMI (QDomDocument & doc, QDomElement & root)
+void JavaANTCodeDocument::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement docElement = doc.createElement(QLatin1String("codedocument"));
+    writer.writeStartElement(QLatin1String("codedocument"));
 
-    setAttributesOnNode(doc, docElement);
+    setAttributesOnNode(writer);
 
-    root.appendChild(docElement);
+    writer.writeEndElement();
 }
 
 // we add in our code blocks that describe how to generate
@@ -257,7 +258,7 @@ QString JavaANTCodeDocument::getPath ()
     QString path = getPackage();
 
     // Replace all white spaces with blanks
-    path.simplified();
+    path = path.simplified();
 
     // Replace all blanks with underscore
     path.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
