@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -26,7 +26,7 @@ public:
     /**
      * Empty Constructor
      */
-    JavaCodeOperation (JavaClassifierCodeDocument * doc, UMLOperation * op, const QString & body = "", const QString & comment = "");
+    JavaCodeOperation (JavaClassifierCodeDocument * doc, UMLOperation * op, const QString & body = QString(), const QString & comment = QString());
 
     /**
      * Empty Destructor
