@@ -43,7 +43,7 @@ public:
     /**
      * Save the XMI representation of this object
      */
-    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
 
     /**
      * @return    QString
