@@ -23,14 +23,14 @@
 #include "classimport.h"
 
 // kde includes
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 /**
  * Constructor.
  * @param file  File to import for which the thread shall be spawned
  */
-CodeImpThread::CodeImpThread(QFileInfo file, QObject* parent)
+CodeImpThread::CodeImpThread(QFileInfo& file, QObject* parent)
   : QObject(parent),
     m_file(file)
 {
@@ -83,7 +83,7 @@ void CodeImpThread::run()
 /**
  * Emit a signal to the main gui thread to show a question box.
  * @param question   the text of the question
- * @return   the code of the answer button @ref KMessageBox::ButtonCode
+ * @return   the code of the answer button KMessageBox::ButtonCode
  */
 int CodeImpThread::emitAskQuestion(const QString& question)
 {
@@ -101,7 +101,11 @@ int CodeImpThread::emitAskQuestion(const QString& question)
  */
 void CodeImpThread::emitMessageToLog(const QString& file, const QString& text)
 {
-    emit messageToLog(file, text);
+    if (file.isEmpty()) {
+        emit messageToLog(m_file.fileName(), text);
+    } else {
+        emit messageToLog(file, text);
+    }
 }
 
 /**
