@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -24,7 +24,7 @@
 
 // kde includes
 #include <khelpmenu.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 // qt includes
 #include <QVBoxLayout>
