@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -41,7 +41,6 @@
 /**
  *  Sets up the AssociationGeneralPage.
  *
- *  @param  d       The UMLDoc which controls controls object creation.
  *  @param  parent  The parent to the AssociationGeneralPage.
  *  @param  assoc   The AssociationWidget to display the properties of.
  */
@@ -140,8 +139,8 @@ void AssociationGeneralPage::constructWidget()
 
         // UMLScene based checks
         if (m_pAssociationWidget->umlScene()->type() == Uml::DiagramType::Collaboration
-                && !(assocType == Uml::AssociationType::Coll_Message_Asynchronous
-                    || assocType == Uml::AssociationType::Coll_Message_Synchronous
+                && !(assocType == Uml::AssociationType::Coll_Mesg_Async
+                    || assocType == Uml::AssociationType::Coll_Mesg_Sync
                     || assocType == Uml::AssociationType::Anchor))
             continue;
 
