@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2021                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -60,8 +60,6 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
     m_pWidget(0),
     m_pInstanceWidget(0),
     m_pUmldoc(d),
-    m_pInstanceL(0),
-    m_pStereoTypeL(0),
     m_pMultiCB(0),
     m_pDrawActorCB(0),
     m_pAbstractCB(0),
@@ -79,6 +77,10 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
         uWarning() << "Given UMLObject is NULL.";
         return;
     }
+    for (int i = 0; i < N_STEREOATTRS; i++) {
+        m_pTagL [i] = 0;
+        m_pTagLE[i] = 0;
+    }
 
     setMinimumSize(310, 330);
     QVBoxLayout * topLayout = new QVBoxLayout(this);
@@ -86,31 +88,40 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
 
     // setup name
     UMLObject::ObjectType t = m_pObject->baseType();
-    QGridLayout * m_pNameLayout = new QGridLayout();
+    m_pNameLayout = new QGridLayout();
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 4);
 
-    if( t == UMLObject::ot_Instance) {
-        Q_ASSERT(m_pObject->asUMLInstance());
+    if (t == UMLObject::ot_Instance) {
+        UMLInstance *inst = m_pObject->asUMLInstance();
+        Q_ASSERT(inst);
         QString name = UMLObject::toI18nString(t);
         m_instanceNameWidget = new UMLObjectNameWidget(name, m_pObject->name());
         m_instanceNameWidget->addToLayout(m_pNameLayout, 0);
-        QString className = UMLObject::toI18nString(UMLObject::ot_Class);
-        m_nameWidget = new UMLObjectNameWidget(className, m_pObject->asUMLInstance()->classifier()->name());
+        setFocusProxy(m_instanceNameWidget);
+        QString classNameLabel = UMLObject::toI18nString(UMLObject::ot_Class);
+        QString className;
+        if (inst->classifier())
+            className = inst->classifier()->name();
+        m_nameWidget = new UMLObjectNameWidget(classNameLabel, className);
         m_nameWidget->addToLayout(m_pNameLayout, 1);
     }
     else {
         QString name = UMLObject::toI18nString(t);
         m_nameWidget = new UMLObjectNameWidget(name, m_pObject->name());
         m_nameWidget->addToLayout(m_pNameLayout, 0);
+        setFocusProxy(m_nameWidget);
     }
 
-    if (t != UMLObject::ot_Stereotype && t!= UMLObject::ot_Instance) {
+    if (t != UMLObject::ot_Stereotype && t != UMLObject::ot_Instance) {
         m_stereotypeWidget = new UMLStereotypeWidget(m_pObject);
         if (t == UMLObject::ot_Interface || t == UMLObject::ot_Datatype || t == UMLObject::ot_Enum) {
             m_stereotypeWidget->setEditable(false);
         }
         m_stereotypeWidget->addToLayout(m_pNameLayout, 1);
+        connect(m_stereotypeWidget->editField(), SIGNAL(currentTextChanged(const QString&)),
+                                          this, SLOT(slotStereoTextChanged(const QString&)));
+        Dialog_Utils::makeTagEditFields(m_pObject, m_pNameLayout, m_pTagL, m_pTagLE);
     }
 
     int row = 2;
@@ -125,7 +136,7 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLObject* o)
         }
     }
 
-    if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface || t == UMLObject::ot_Enum) {
+    if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface || t == UMLObject::ot_Enum || t == UMLObject::ot_Entity) {
         m_packageWidget = new UMLPackageWidget(m_pObject);
         m_packageWidget->addToLayout(m_pNameLayout, row);
         ++row;
@@ -172,8 +183,6 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     m_pWidget(o),
     m_pInstanceWidget(0),
     m_pUmldoc(d),
-    m_pInstanceL(0),
-    m_pStereoTypeL(0),
     m_pMultiCB(0),
     m_pDrawActorCB(0),
     m_pAbstractCB(0),
@@ -191,19 +200,24 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
         uWarning() << "Given ObjectWidget is NULL.";
         return;
     }
+    for (int i = 0; i < N_STEREOATTRS; i++) {
+        m_pTagL [i] = 0;
+        m_pTagLE[i] = 0;
+    }
 
     setMinimumSize(310, 330);
     QVBoxLayout * topLayout = new QVBoxLayout(this);
     topLayout->setSpacing(6);
 
     // setup name
-    QGridLayout * m_pNameLayout = new QGridLayout();
+    m_pNameLayout = new QGridLayout();
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 4);
 
     QString name = UMLObject::toI18nString(UMLObject::ot_Instance);
     m_instanceNameWidget = new UMLObjectNameWidget(name , m_pWidget->instanceName());
     m_instanceNameWidget->addToLayout(m_pNameLayout, 0);
+    setFocusProxy(m_instanceNameWidget);
 
     QString className = UMLObject::toI18nString(UMLObject::ot_Class);
     m_nameWidget = new UMLObjectNameWidget(className, m_pWidget->name());
@@ -215,7 +229,7 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     m_pDrawActorCB->setChecked(m_pWidget->drawAsActor());
     m_pNameLayout->addWidget(m_pDrawActorCB, 2, 0);
 
-    if (view->umlScene()->type() == Uml::DiagramType::Collaboration) {
+    if (view->umlScene()->isCollaborationDiagram()) {
         m_pMultiCB = new QCheckBox(i18n("Multiple instance"), this);
         m_pMultiCB->setChecked(m_pWidget->multipleInstance());
         m_pNameLayout->addWidget(m_pMultiCB, 2, 1);
@@ -240,8 +254,6 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLWidget* widget
     m_pWidget(0),
     m_pInstanceWidget(widget),
     m_pUmldoc(d),
-    m_pInstanceL(0),
-    m_pStereoTypeL(0),
     m_pMultiCB(0),
     m_pDrawActorCB(0),
     m_pAbstractCB(0),
@@ -255,18 +267,24 @@ ClassGeneralPage::ClassGeneralPage(UMLDoc* d, QWidget* parent, UMLWidget* widget
     m_artifactTypeWidget(0),
     m_visibilityEnumWidget(0)
 {
+    for (int i = 0; i < N_STEREOATTRS; i++) {
+        m_pTagL [i] = 0;
+        m_pTagLE[i] = 0;
+    }
+
     setMinimumSize(310, 330);
     QVBoxLayout * topLayout = new QVBoxLayout(this);
     topLayout->setSpacing(6);
 
     // setup name
-    QGridLayout * m_pNameLayout = new QGridLayout();
+    m_pNameLayout = new QGridLayout();
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 4);
 
     QString typeName = UMLWidget::toI18nString(widget->baseType());
     m_nameWidget = new UMLObjectNameWidget(typeName, widget->name());
     m_nameWidget->addToLayout(m_pNameLayout, 0);
+    setFocusProxy(m_nameWidget);
 
     if (widget->umlObject()) {
         m_stereotypeWidget = new UMLStereotypeWidget(widget->umlObject());
@@ -285,6 +303,11 @@ ClassGeneralPage::~ClassGeneralPage()
 {
 }
 
+void ClassGeneralPage::slotStereoTextChanged(const QString &stereoText)
+{
+    Dialog_Utils::remakeTagEditFields(stereoText, m_pObject, m_pNameLayout, m_pTagL, m_pTagLE);
+}
+
 /**
  * Will move information from the dialog into the object.
  * Call when the ok or apply button is pressed.
@@ -296,11 +319,14 @@ void ClassGeneralPage::apply()
 
     if (m_stereotypeWidget) {
         m_stereotypeWidget->apply();
+        if (m_pObject) {
+            Dialog_Utils::updateTagsFromEditFields(m_pObject, m_pTagLE);
+        }
     }
 
     if (m_pObject) {
         UMLObject::ObjectType t = m_pObject->baseType();
-        if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface || t == UMLObject::ot_Enum) {
+        if (t == UMLObject::ot_Class || t == UMLObject::ot_Interface || t == UMLObject::ot_Enum || t == UMLObject::ot_Entity) {
             m_packageWidget->apply();
         }
 
@@ -310,7 +336,6 @@ void ClassGeneralPage::apply()
 
         if(m_instanceNameWidget && m_pObject->isUMLInstance()) {
             m_pObject->asUMLInstance()->setName(m_instanceNameWidget->text());
-            m_pObject->asUMLInstance()->setClassifierName(m_nameWidget->text());
         }
 
         //make sure unique name
