@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -18,6 +18,7 @@
 #include "template.h"
 #include "umldoc.h"
 #include "uml.h"
+#include "umldatatypewidget.h"
 #include "umlstereotypewidget.h"
 #include "visibilityenumwidget.h"
 #include "dialog_utils.h"
@@ -28,8 +29,8 @@
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kcompletion.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // qt includes
 #include <QCheckBox>
@@ -46,6 +47,10 @@ UMLAttributeDialog::UMLAttributeDialog(QWidget * pParent, UMLAttribute * pAttrib
 {
     setCaption(i18n("Attribute Properties"));
     m_pAttribute = pAttribute;
+    for (int i = 0; i < N_STEREOATTRS; i++) {
+        m_pTagL [i] = 0;
+        m_pTagLE[i] = 0;
+    }
     setupDialog();
 }
 
@@ -65,42 +70,35 @@ void UMLAttributeDialog::setupDialog()
     QVBoxLayout * mainLayout = new QVBoxLayout(frame);
 
     m_pValuesGB = new QGroupBox(i18n("General Properties"), frame);
-    QGridLayout * valuesLayout = new QGridLayout(m_pValuesGB);
-    valuesLayout->setMargin(margin);
-    valuesLayout->setSpacing(10);
+    m_pValuesLayout = new QGridLayout(m_pValuesGB);
+    m_pValuesLayout->setMargin(margin);
+    m_pValuesLayout->setSpacing(10);
 
-    m_pTypeL = new QLabel(i18n("&Type:"), m_pValuesGB);
-    valuesLayout->addWidget(m_pTypeL, 0, 0);
+    m_datatypeWidget = new UMLDatatypeWidget(m_pAttribute->asUMLClassifierListItem());
+    m_datatypeWidget->addToLayout(m_pValuesLayout, 0);
 
-    m_pTypeCB = new KComboBox(true, m_pValuesGB);
-    valuesLayout->addWidget(m_pTypeCB, 0, 1);
-    m_pTypeL->setBuddy(m_pTypeCB);
-
-    Dialog_Utils::makeLabeledEditField(valuesLayout, 1,
+    Dialog_Utils::makeLabeledEditField(m_pValuesLayout, 1,
                                     m_pNameL, i18nc("attribute name", "&Name:"),
                                     m_pNameLE, m_pAttribute->name());
 
-    Dialog_Utils::makeLabeledEditField(valuesLayout, 2,
+    Dialog_Utils::makeLabeledEditField(m_pValuesLayout, 2,
                                     m_pInitialL, i18n("&Initial value:"),
                                     m_pInitialLE, m_pAttribute->getInitialValue());
 
     m_stereotypeWidget = new UMLStereotypeWidget(m_pAttribute);
-    m_stereotypeWidget->addToLayout(valuesLayout, 3);
+    m_stereotypeWidget->addToLayout(m_pValuesLayout, 3);
+    connect(m_stereotypeWidget->editField(), SIGNAL(currentTextChanged(const QString&)),
+                                       this, SLOT(slotStereoTextChanged(const QString&)));
+    Dialog_Utils::makeTagEditFields(m_pAttribute, m_pValuesLayout, m_pTagL, m_pTagLE, 3);
 
     m_pStaticCB = new QCheckBox(i18n("Classifier &scope (\"static\")"), m_pValuesGB);
     m_pStaticCB->setChecked(m_pAttribute->isStatic());
-    valuesLayout->addWidget(m_pStaticCB, 4, 0);
+    m_pValuesLayout->addWidget(m_pStaticCB, 4, 0);
 
     mainLayout->addWidget(m_pValuesGB);
     m_visibilityEnumWidget = new VisibilityEnumWidget(m_pAttribute, this);
     m_visibilityEnumWidget->addToLayout(mainLayout);
 
-    m_pTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
-    m_pTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
-
-    //now add the Concepts
-    insertTypesSorted(m_pAttribute->getTypeName());
-
     m_docWidget = new DocumentationWidget(m_pAttribute, this);
     mainLayout->addWidget(m_docWidget);
 
@@ -114,6 +112,11 @@ void UMLAttributeDialog::slotNameChanged(const QString &_text)
     enableButtonOk(!_text.isEmpty());
 }
 
+void UMLAttributeDialog::slotStereoTextChanged(const QString &stereoText)
+{
+    Dialog_Utils::remakeTagEditFields(stereoText, m_pAttribute, m_pValuesLayout, m_pTagL, m_pTagLE);
+}
+
 /**
  * Checks if changes are valid and applies them if they are,
  * else returns false
@@ -127,99 +130,27 @@ bool UMLAttributeDialog::apply()
         m_pNameLE->setText(m_pAttribute->name());
         return false;
     }
-    UMLClassifier * pConcept = dynamic_cast<UMLClassifier *>(m_pAttribute->parent());
-    UMLObject *o = pConcept->findChildObject(name);
+    UMLClassifier * pConcept = m_pAttribute->umlParent()->asUMLClassifier();
+    UMLObject *o = pConcept ? pConcept->findChildObject(name) : 0;
     if (o && o != m_pAttribute) {
         KMessageBox::error(this, i18n("The attribute name you have chosen is already being used in this operation."),
                            i18n("Attribute Name Not Unique"), 0);
         m_pNameLE->setText(m_pAttribute->name());
         return false;
     }
-    m_pAttribute->setName(name);
+    m_pAttribute->blockSignals(true);
     m_visibilityEnumWidget->apply();
-
-    // Set the scope as the default in the option state
-    Settings::OptionState optionState = Settings::optionState();
-    optionState.classState.defaultAttributeScope = m_pAttribute->visibility();
-    Settings::setOptionState(optionState);
-
     m_pAttribute->setInitialValue(m_pInitialLE->text());
     m_stereotypeWidget->apply();
+    Dialog_Utils::updateTagsFromEditFields(m_pAttribute, m_pTagLE);
     m_pAttribute->setStatic(m_pStaticCB->isChecked());
-
-    QString typeName = m_pTypeCB->currentText();
-    UMLTemplate *tmplParam = pConcept->findTemplate(typeName);
-    if (tmplParam) {
-        m_pAttribute->setType(tmplParam);
-        return true;
-    }
-    UMLDoc * pDoc = UMLApp::app()->document();
-
-    UMLObject *obj = 0;
-    if (!typeName.isEmpty()) {
-        obj = pDoc->findUMLObject(typeName);
-    }
-
-    UMLClassifier *classifier = dynamic_cast<UMLClassifier*>(obj);
-    if (classifier == NULL) {
-        Uml::ProgrammingLanguage::Enum pl = UMLApp::app()->activeLanguage();
-        // Import_Utils does not handle creating a new object with empty name
-        // string well. Use Object_Factory in those cases.
-        if (
-            (!typeName.isEmpty()) &&
-            ((pl == Uml::ProgrammingLanguage::Cpp) ||
-                (pl == Uml::ProgrammingLanguage::Java))
-        ) {
-            // Import_Utils::createUMLObject works better for C++ namespace
-            // and java package than Object_Factory::createUMLObject
-            Import_Utils::setRelatedClassifier(pConcept);
-            obj = Import_Utils::createUMLObject(UMLObject::ot_UMLObject, typeName);
-            Import_Utils::setRelatedClassifier(NULL);
-        } else {
-            // If it's obviously a pointer type (C++) then create a datatype.
-            // Else we don't know what it is so as a compromise create a class.
-            UMLObject::ObjectType ot =
-                (typeName.contains(QChar::fromLatin1('*')) ? UMLObject::ot_Datatype
-                                                          : UMLObject::ot_Class);
-            obj = Object_Factory::createUMLObject(ot, typeName);
-        }
-        if (obj == NULL)
-            return false;
-        classifier = static_cast<UMLClassifier*>(obj);
-    }
-    m_pAttribute->setType(classifier);
+    m_datatypeWidget->apply();
     m_docWidget->apply();
+    m_pAttribute->blockSignals(false);
+    // trigger signals
+    m_pAttribute->setName(name);
 
+    // Set the scope as the default in the option state
+    Settings::optionState().classState.defaultAttributeScope = m_pAttribute->visibility();
     return true;
 }
-
-/**
- * Inserts @p type into the type-combobox as well as its completion object.
- * The combobox is cleared and all types together with the optional new one
- * sorted and then added again.
- * @param type   a new type to add
- */
-void UMLAttributeDialog::insertTypesSorted(const QString& type)
-{
-    UMLDoc * uDoc = UMLApp::app()->document();
-    UMLClassifierList namesList(uDoc->concepts());
-    QStringList types;
-    foreach (UMLClassifier* obj, namesList) {
-         types << obj->fullyQualifiedName();
-    }
-    if (!types.contains(type)) {
-        types << type;
-    }
-    types.sort();
-
-    m_pTypeCB->clear();
-    m_pTypeCB->insertItems(-1, types);
-
-    int currentIndex = m_pTypeCB->findText(type);
-    if (currentIndex > -1) {
-        m_pTypeCB->setCurrentIndex(currentIndex);
-    }
-    m_pTypeCB->completionObject()->addItem(type);
-}
-
-#include "umlattributedialog.moc"
