@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -112,24 +112,9 @@ Uml::AssociationType::Enum UMLAssociation::getAssocType() const
  */
 QString UMLAssociation::toString() const
 {
-    QString string;
-    if(m_pRole[RoleType::A])
-    {
-        string += m_pRole[RoleType::A]->object()->name();
-        string += QLatin1Char(':');
-        string += m_pRole[RoleType::A]->name();
-    } else {
-        string += QLatin1String("null");
-    }
+    QString string = m_pRole[RoleType::A]->toString();
     string += QLatin1Char(' ') + Uml::AssociationType::toStringI18n(m_AssocType) + QLatin1Char(' ');
-    if(m_pRole[RoleType::B])
-    {
-        string += m_pRole[RoleType::B]->object()->name();
-        string += QLatin1Char(':');
-        string += m_pRole[RoleType::B]->name();
-    } else {
-        string += QLatin1String("null");
-    }
+    string += m_pRole[RoleType::B]->toString();
     return string;
 }
 
@@ -161,61 +146,57 @@ bool UMLAssociation::resolveRef()
  * Creates the <UML:Generalization> or <UML:Association> XMI element
  * including its role objects.
  */
-void UMLAssociation::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
+void UMLAssociation::saveToXMI1(QXmlStreamWriter& writer)
 {
     if (m_AssocType == Uml::AssociationType::Generalization) {
-        QDomElement assocElement = UMLObject::save1(QLatin1String("UML:Generalization"), qDoc);
-        assocElement.setAttribute(QLatin1String("discriminator"), QString());
-        assocElement.setAttribute(QLatin1String("child"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("parent"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(QLatin1String("UML:Generalization"), writer);
+        writer.writeAttribute(QLatin1String("discriminator"), QString());
+        writer.writeAttribute(QLatin1String("child"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("parent"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Realization) {
-        QDomElement assocElement = UMLObject::save1(QLatin1String("UML:Abstraction"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(QLatin1String("UML:Abstraction"), writer);
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Dependency) {
-        QDomElement assocElement = UMLObject::save1(QLatin1String("UML:Dependency"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(QLatin1String("UML:Dependency"), writer);
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Child2Category) {
-        QDomElement assocElement = UMLObject::save1(QLatin1String("UML:Child2Category"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(QLatin1String("UML:Child2Category"), writer);
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Category2Parent) {
-        QDomElement assocElement = UMLObject::save1(QLatin1String("UML:Category2Parent"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(QLatin1String("UML:Category2Parent"), writer);
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
 
-    QDomElement associationElement = UMLObject::save1(QLatin1String("UML:Association"), qDoc);
-    QDomElement connElement = qDoc.createElement(QLatin1String("UML:Association.connection"));
-    getUMLRole(RoleType::A)->saveToXMI1 (qDoc, connElement);
-    getUMLRole(RoleType::B)->saveToXMI1 (qDoc, connElement);
-    associationElement.appendChild (connElement);
-    qElement.appendChild(associationElement);
+    UMLObject::save1(QLatin1String("UML:Association"), writer);
+    writer.writeStartElement(QLatin1String("UML:Association.connection"));
+    getUMLRole(RoleType::A)->saveToXMI1 (writer);
+    getUMLRole(RoleType::B)->saveToXMI1 (writer);
+    writer.writeEndElement();            // UML:Association.connection
+    writer.writeEndElement();  // UML:Association
 }
 
 bool UMLAssociation::showPropertiesDialog(QWidget *parent)
 {
     QPointer<ClassPropertiesDialog> dlg = new ClassPropertiesDialog(parent, this, true);
-    bool modified = false;
-    if (dlg->exec()) {
-        modified = true;
-    }
-    dlg->close();
+    bool modified = dlg->exec();
     delete dlg;
     return modified;
 }
@@ -387,7 +368,7 @@ bool UMLAssociation::load1(QDomElement & element)
         // setting the association type:
         //
         // In the old days, we could just record this on the association,
-        // and be done with it. But thats not how the UML13.dtd does things.
+        // and be done with it. But that's not how the UML13.dtd does things.
         // As a result, we are checking roleA for information about the
         // parent association (!) which by this point in the parse, should
         // be set. However, the information that the roles are allowed to have
@@ -418,7 +399,7 @@ bool UMLAssociation::load1(QDomElement & element)
                     "associationself",  // Uml::AssociationType::Association_Self
                     "collmessage",      // Uml::AssociationType::Coll_Message
                     "seqmessage",       // Uml::AssociationType::Seq_Message
-                    "collmessageself",  // Uml::AssociationType::Coll_Message_Self
+                    "collmessageself",  // Uml::AssociationType::Coll_Mesg_Self
                     "seqmessageself",   // Uml::AssociationType::Seq_Message_Self
                     "implementation",   // Uml::AssociationType::Implementation
                     "composition",      // Uml::AssociationType::Composition
