@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2020                                               *
+ *   copyright (C) 2002-2021                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 #include "classifier.h"
@@ -1231,16 +1231,6 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
             }
             break;
         }
-    case UMLObject::ot_InstanceAttribute: {
-        UMLInstanceAttribute *ia = subordinates().takeAt(index)->asUMLInstanceAttribute();
-        if(ia) {
-            emit attributeRemoved(ia);
-            UMLObject::emitModified();
-        } else {
-            index = -1;
-        }
-        break;
-    }
         default:
             index = -1;
             break;
@@ -1358,7 +1348,7 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented()
  * Saves possible template parameters, generalizations, attributes,
  * operations, and contained objects to the given QDomElement.
  */
-void UMLClassifier::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
+void UMLClassifier::saveToXMI1(QXmlStreamWriter& writer)
 {
     QString tag;
     switch (m_BaseType) {
@@ -1369,69 +1359,67 @@ void UMLClassifier::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
             tag = QLatin1String("UML:Interface");
             break;
         case UMLObject::ot_Package:
-            UMLPackage::saveToXMI1(qDoc, qElement);
+            UMLPackage::saveToXMI1(writer);
             return;
             break;
         default:
             uError() << "internal error: basetype is " << m_BaseType;
             return;
     }
-    QDomElement classifierElement = UMLObject::save1(tag, qDoc);
+    UMLObject::save1(tag, writer);
 
     //save templates
     UMLClassifierListItemList list = getFilteredList(UMLObject::ot_Template);
     if (list.count()) {
-        QDomElement tmplElement = qDoc.createElement(QLatin1String("UML:ModelElement.templateParameter"));
+        writer.writeStartElement(QLatin1String("UML:ModelElement.templateParameter"));
         foreach (UMLClassifierListItem *tmpl, list) {
-            tmpl->saveToXMI1(qDoc, tmplElement);
+            tmpl->saveToXMI1(writer);
         }
-        classifierElement.appendChild(tmplElement);
+        writer.writeEndElement();
     }
 
     //save generalizations (we are the subclass, the other end is the superclass)
     UMLAssociationList generalizations = getSpecificAssocs(AssociationType::Generalization);
     if (generalizations.count()) {
-        QDomElement genElement = qDoc.createElement(QLatin1String("UML:GeneralizableElement.generalization"));
+        writer.writeStartElement(QLatin1String("UML:GeneralizableElement.generalization"));
         foreach (UMLAssociation *a, generalizations) {
             // We are the subclass if we are at the role A end.
             if (m_nId != a->getObjectId(RoleType::A)) {
                 continue;
             }
-            QDomElement gElem = qDoc.createElement(QLatin1String("UML:Generalization"));
-            gElem.setAttribute(QLatin1String("xmi.idref"), Uml::ID::toString(a->id()));
-            genElement.appendChild(gElem);
-        }
-        if (genElement.hasChildNodes()) {
-            classifierElement.appendChild(genElement);
+            writer.writeStartElement(QLatin1String("UML:Generalization"));
+            writer.writeAttribute(QLatin1String("xmi.idref"), Uml::ID::toString(a->id()));
+            writer.writeEndElement();
         }
+        writer.writeEndElement();
     }
 
-    // save attributes
-    QDomElement featureElement = qDoc.createElement(QLatin1String("UML:Classifier.feature"));
     UMLClassifierListItemList attList = getFilteredList(UMLObject::ot_Attribute);
-    foreach (UMLClassifierListItem *pAtt, attList) {
-        pAtt->saveToXMI1(qDoc, featureElement);
-    }
+    UMLOperationList          opList  = getOpList();
 
-    // save operations
-    UMLOperationList opList = getOpList();
-    foreach (UMLOperation *pOp, opList) {
-        pOp->saveToXMI1(qDoc, featureElement);
-    }
-    if (featureElement.hasChildNodes()) {
-        classifierElement.appendChild(featureElement);
+    if (attList.count() || opList.count()) {
+        writer.writeStartElement(QLatin1String("UML:Classifier.feature"));
+        // save attributes
+        foreach (UMLClassifierListItem *pAtt, attList) {
+            pAtt->saveToXMI1(writer);
+        }
+        // save operations
+        foreach (UMLOperation *pOp, opList) {
+            pOp->saveToXMI1(writer);
+        }
+        writer.writeEndElement();
     }
 
     // save contained objects
     if (m_objects.count()) {
-        QDomElement ownedElement = qDoc.createElement(QLatin1String("UML:Namespace.ownedElement"));
+        writer.writeStartElement(QLatin1String("UML:Namespace.ownedElement"));
         foreach (UMLObject* obj, m_objects) {
             uIgnoreZeroPointer(obj);
-            obj->saveToXMI1 (qDoc, ownedElement);
+            obj->saveToXMI1 (writer);
         }
-        classifierElement.appendChild(ownedElement);
+        writer.writeEndElement();
     }
-    qElement.appendChild(classifierElement);
+    UMLObject::save1end(writer);   // from UMLObject::save1(tag)
 }
 
 /**
