@@ -437,22 +437,22 @@ bool UMLPackage::resolveRef()
 /**
  * Creates the <UML:Package> XMI element.
  */
-void UMLPackage::saveToXMI1(QDomDocument& qDoc, QDomElement& qElement)
+void UMLPackage::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement packageElement = UMLObject::save1(QLatin1String("UML:Package"), qDoc);
-    QDomElement ownedElement = qDoc.createElement(QLatin1String("UML:Namespace.ownedElement"));
+    UMLObject::save1(QLatin1String("UML:Package"), writer);
+    writer.writeStartElement(QLatin1String("UML:Namespace.ownedElement"));
     // save classifiers etc.
     foreach (UMLObject *obj, m_objects) {
         uIgnoreZeroPointer(obj);
-        obj->saveToXMI1 (qDoc, ownedElement);
+        obj->saveToXMI1 (writer);
     }
     // save associations
     foreach (UMLObject *obj, subordinates()) {
-        obj->saveToXMI1 (qDoc, ownedElement);
+        obj->saveToXMI1 (writer);
     }
 
-    packageElement.appendChild(ownedElement);
-    qElement.appendChild(packageElement);
+    writer.writeEndElement();            // UML:Namespace.ownedElement
+    UMLObject::save1end(writer); // UML:Package
 }
 
 /**
@@ -482,8 +482,9 @@ bool UMLPackage::load1(QDomElement& element)
                    UMLDoc::tagEq(type, QLatin1String("ownedElement"))) {
             type = tempElement.attribute(QLatin1String("xmi:type"));
         }
-        UMLObject *pObject = Object_Factory::makeObjectFromXMI(type);
-        if(!pObject) {
+        QString stereoID = tempElement.attribute(QLatin1String("stereotype"));
+        UMLObject *pObject = Object_Factory::makeObjectFromXMI(type, stereoID);
+        if (!pObject) {
             uWarning() << "Unknown type of umlobject to create: " << type;
             continue;
         }
