@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2020                                               *
+ *   copyright (C) 2003-2021                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -211,7 +211,7 @@ QString UMLCanvasObject::uniqChildName(const UMLObject::ObjectType type,
             case UMLObject::ot_CheckConstraint:
                 currentName = i18n("new_check_constraint");
                 break;
-            case UMLObject::ot_InstanceAttribute:
+            case UMLObject::ot_Instance:
                 currentName = i18n("new_object");
             break;
             default:
