@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -45,6 +45,7 @@
 #include <QRegExp>
 #include <QPainter>
 #include <QValidator>
+#include <QXmlStreamWriter>
 
 DEBUG_REGISTER_DISABLED(FloatingTextWidget)
 
@@ -225,91 +226,50 @@ void FloatingTextWidget::showChangeTextDialog()
  *
  * @param enableAutoIncrement Enable auto increment checkbox
  */
-void FloatingTextWidget::showOperationDialog(bool enableAutoIncrement)
+bool FloatingTextWidget::showOperationDialog(bool enableAutoIncrement)
 {
     if (!m_linkWidget) {
         uError() << "m_linkWidget is NULL";
-        return;
+        return false;
     }
-    QString seqNum = m_linkWidget->sequenceNumber();
-    UMLClassifier* c = m_linkWidget->lwClassifier();
-    QString opText = m_linkWidget->lwOperationText();
-    if (!c) {
+    if (!m_linkWidget->lwClassifier()) {
         uError() << "m_linkWidget->lwClassifier() returns a NULL classifier";
-        return;
+        return false;
     }
+    bool result = false;
 
-    QPointer<SelectOperationDialog> selectDialog = new SelectOperationDialog(m_scene->activeView(), c, enableAutoIncrement);
-    if (enableAutoIncrement && m_scene->autoIncrementSequence()) {
-        seqNum = m_scene->autoIncrementSequenceValue();
-        selectDialog->setAutoIncrementSequence(true);
-    }
-    selectDialog->setSeqNumber(seqNum);
-    if (m_linkWidget->operation() == 0) {
-        selectDialog->setCustomOp(opText);
-    } else {
-        selectDialog->setClassOp(opText);
-    }
+    QPointer<SelectOperationDialog> selectDialog = new SelectOperationDialog(m_scene->activeView(), m_linkWidget->lwClassifier(), m_linkWidget, enableAutoIncrement);
     if (selectDialog->exec()) {
-        seqNum = selectDialog->getSeqNumber();
-        opText = selectDialog->getOpText();
-        if (selectDialog->isClassOp()) {
-            Model_Utils::OpDescriptor od;
-            Model_Utils::Parse_Status st = Model_Utils::parseOperation(opText, od, c);
-            if (st == Model_Utils::PS_OK) {
-                UMLClassifierList selfAndAncestors = c->findSuperClassConcepts();
-                selfAndAncestors.prepend(c);
-                UMLOperation *op = 0;
-                foreach (UMLClassifier *cl, selfAndAncestors) {
-                    op = cl->findOperation(od.m_name, od.m_args);
-                    if (op) {
-                        break;
-                    }
-                }
-                if (!op) {
-                    // The op does not yet exist. Create a new one.
-                    UMLObject *o = c->createOperation(od.m_name, 0, &od.m_args);
-                    op = o->asUMLOperation();
-                }
-                if (od.m_pReturnType) {
-                    op->setType(od.m_pReturnType);
-                }
-
-                m_linkWidget->setOperation(op);
-                opText.clear();
-            } else {
-                m_linkWidget->setOperation(0);
-            }
-        } else {
-            m_linkWidget->setOperation(0);
-        }
-        m_linkWidget->setSequenceNumber(seqNum);
-        m_linkWidget->setOperationText(opText);
-        if (enableAutoIncrement) {
-            m_scene->setAutoIncrementSequence(selectDialog->autoIncrementSequence());
-        }
+        selectDialog->apply();
         setMessageText();
+        result = true;
     }
     delete selectDialog;
+    return result;
 }
 
 /**
  * Show the properties for a FloatingTextWidget.
- * Depending on the role of the floating text wiget, the options dialog
+ * Depending on the role of the floating text widget, the options dialog
  * for the floating text widget, the rename dialog for floating text or
  * the options dialog for the link widget are shown.
  */
-void FloatingTextWidget::showPropertiesDialog()
+bool FloatingTextWidget::showPropertiesDialog()
 {
-    if (m_textRole == Uml::TextRole::Coll_Message || m_textRole == Uml::TextRole::Coll_Message_Self ||
+    UMLWidget *p = dynamic_cast<UMLWidget*>(parentItem());
+    if (p && p->isInterfaceWidget()) {
+        if (p->showPropertiesDialog())
+            setText(p->name());
+    } else if (m_textRole == Uml::TextRole::Coll_Message || m_textRole == Uml::TextRole::Coll_Message_Self ||
             m_textRole == Uml::TextRole::Seq_Message || m_textRole == Uml::TextRole::Seq_Message_Self) {
-        showOperationDialog(false);
+        return showOperationDialog(false);
     } else if (m_textRole == Uml::TextRole::Floating) {
         // double clicking on a text line opens the dialog to change the text
-        handleRename();
+        return handleRename();
     } else if (m_linkWidget) {
-        m_linkWidget->showPropertiesDialog();
+        return m_linkWidget->showPropertiesDialog();
     }
+    return false;
 }
 
 /**
@@ -391,7 +351,7 @@ Uml::TextRole::Enum FloatingTextWidget::textRole() const
  * Handle the ListPopupMenu::mt_Rename case of the slotMenuSelection.
  * Given an own method because it requires rather lengthy code.
  */
-void FloatingTextWidget::handleRename()
+bool FloatingTextWidget::handleRename()
 {
     QString t;
     if (m_textRole == Uml::TextRole::RoleAName || m_textRole == Uml::TextRole::RoleBName) {
@@ -413,10 +373,11 @@ void FloatingTextWidget::handleRename()
     QString newText = text();
     bool ok = Dialog_Utils::askName(i18n("Rename"), t, newText);
     if (!ok || newText == text()) {
-        return;
+        return false;
     }
 
     UMLApp::app()->executeCommand(new Uml::CmdHandleRename(this, newText));
+    return true;
 }
 
 /**
@@ -561,7 +522,8 @@ void FloatingTextWidget::moveWidgetBy(qreal diffX, qreal diffY)
         return;
 
     if (textRole() == Uml::TextRole::Seq_Message
-                    && ((MessageWidget*)link())->isSelected()) {
+            && link() && dynamic_cast<MessageWidget*>(link())
+            && dynamic_cast<MessageWidget*>(link())->isSelected()) {
         return;
     }
 
@@ -712,24 +674,24 @@ bool FloatingTextWidget::loadFromXMI1(QDomElement & qElement)
  * Reimplemented from UMLWidget::saveToXMI1 to save the widget
  * data into XMI 'floatingtext' element.
  */
-void FloatingTextWidget::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
+void FloatingTextWidget::saveToXMI1(QXmlStreamWriter& writer)
 {
     if (isEmpty())
         return;
 
-    QDomElement textElement = qDoc.createElement(QLatin1String("floatingtext"));
-    UMLWidget::saveToXMI1(qDoc, textElement);
-    textElement.setAttribute(QLatin1String("text"), m_Text);
-    textElement.setAttribute(QLatin1String("pretext"), m_preText);
-    textElement.setAttribute(QLatin1String("posttext"), m_postText);
+    writer.writeStartElement(QLatin1String("floatingtext"));
+    UMLWidget::saveToXMI1(writer);
+    writer.writeAttribute(QLatin1String("text"), m_Text);
+    writer.writeAttribute(QLatin1String("pretext"), m_preText);
+    writer.writeAttribute(QLatin1String("posttext"), m_postText);
 
     /* No need to save these - the messagewidget already did it.
     m_Operation  = qElement.attribute("operation");
     m_SeqNum = qElement.attribute("seqnum");
      */
 
-    textElement.setAttribute(QLatin1String("role"), m_textRole);
-    qElement.appendChild(textElement);
+    writer.writeAttribute(QLatin1String("role"), QString::number(m_textRole));
+    writer.writeEndElement();
 }
 
 /**
