@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -24,23 +24,20 @@
 
 // kde includes
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <kinputdialog.h>
-#endif
 
 // qt includes
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
 #include <QPainter>
 #include <QPointer>
+#include <QXmlStreamWriter>
 
-#define OBJECTNODE_MARGIN 5
-#define OBJECTNODE_WIDTH 30
+#define OBJECTNODE_MARGIN  5
+#define OBJECTNODE_WIDTH  30
 #define OBJECTNODE_HEIGHT 10
 
+DEBUG_REGISTER_DISABLED(ObjectNodeWidget)
+
 /**
- * Creates a Object Node widget.
+ * Creates an Object Node widget.
  *
  * @param scene            The parent of the widget.
  * @param objectNodeType   The type of object node
@@ -236,19 +233,10 @@ void ObjectNodeWidget::slotMenuSelection(QAction* action)
     switch(sel) {
     case ListPopupMenu::mt_Rename:
         {
-            bool ok = false;
             QString text = name();
-#if QT_VERSION >= 0x050000
-            text = QInputDialog::getText(Q_NULLPTR,
-                                         i18n("Enter Object Node Name"),
-                                         i18n("Enter the name of the object node :"),
-                                         QLineEdit::Normal,
-                                         name(), &ok);
-#else
-            text = KInputDialog::getText(i18n("Enter Object Node Name"),
-                                          i18n("Enter the name of the object node :"),
-                                          name(), &ok);
-#endif
+            bool ok = Dialog_Utils::askName(i18n("Enter Object Node Name"),
+                                            i18n("Enter the name of the object node :"),
+                                            text);
             if (ok && !text.isEmpty()) {
                 setName(text);
             }
@@ -267,38 +255,41 @@ void ObjectNodeWidget::slotMenuSelection(QAction* action)
 /**
  * Show a properties dialog for an ObjectNodeWidget.
  */
-void ObjectNodeWidget::showPropertiesDialog()
+bool ObjectNodeWidget::showPropertiesDialog()
 {
     UMLApp::app()->docWindow()->updateDocumentation(false);
 
+    bool result = false;
     QPointer<ObjectNodeDialog> dialog = new ObjectNodeDialog(UMLApp::app()->currentView(), this);
     if (dialog->exec() && dialog->getChangesMade()) {
         UMLApp::app()->docWindow()->showDocumentation(this, true);
         UMLApp::app()->document()->setModified(true);
+        result = true;
     }
     delete dialog;
+    return result;
 }
 
 /**
  * Saves the widget to the "objectnodewidget" XMI element.
  */
-void ObjectNodeWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+void ObjectNodeWidget::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement objectNodeElement = qDoc.createElement(QLatin1String("objectnodewidget"));
-    UMLWidget::saveToXMI(qDoc, objectNodeElement);
-    objectNodeElement.setAttribute(QLatin1String("objectnodename"), m_Text);
-    objectNodeElement.setAttribute(QLatin1String("documentation"), m_Doc);
-    objectNodeElement.setAttribute(QLatin1String("objectnodetype"), m_objectNodeType);
-    objectNodeElement.setAttribute(QLatin1String("objectnodestate"), m_state);
-    qElement.appendChild(objectNodeElement);
+    writer.writeStartElement(QLatin1String("objectnodewidget"));
+    UMLWidget::saveToXMI1(writer);
+    writer.writeAttribute(QLatin1String("objectnodename"), m_Text);
+    writer.writeAttribute(QLatin1String("documentation"), m_Doc);
+    writer.writeAttribute(QLatin1String("objectnodetype"), QString::number(m_objectNodeType));
+    writer.writeAttribute(QLatin1String("objectnodestate"), m_state);
+    writer.writeEndElement();
 }
 
 /**
  * Loads the widget from the "objectnodewidget" XMI element.
  */
-bool ObjectNodeWidget::loadFromXMI(QDomElement& qElement)
+bool ObjectNodeWidget::loadFromXMI1(QDomElement& qElement)
 {
-    if(!UMLWidget::loadFromXMI(qElement) )
+    if(!UMLWidget::loadFromXMI1(qElement) )
         return false;
     m_Text = qElement.attribute(QLatin1String("objectnodename"));
     m_Doc = qElement.attribute(QLatin1String("documentation"));
@@ -352,16 +343,10 @@ void ObjectNodeWidget::askForObjectNodeType(UMLWidget* &targetWidget)
  */
 void ObjectNodeWidget::askStateForWidget()
 {
-    bool pressedOK = false;
-#if QT_VERSION >= 0x050000
-    QString state = QInputDialog::getText(UMLApp::app(),
-                                          i18n("Enter Object Flow State"), i18n("Enter State (keep '-' if there is no state for the object) "),
-                                          QLineEdit::Normal,
-                                          i18n("-"), &pressedOK);
-#else
-    QString state = KInputDialog::getText(i18n("Enter Object Flow State"), i18n("Enter State (keep '-' if there is no state for the object) "), i18n("-"), &pressedOK, UMLApp::app());
-#endif
-
+    QString state = i18n("-");
+    bool pressedOK = Dialog_Utils::askName(i18n("Enter Object Flow State"),
+                                           i18n("Enter State (keep '-' if there is no state for the object) "),
+                                           state);
     if (pressedOK) {
         setState(state);
     } else {
