@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -14,6 +14,7 @@
 // local includes
 #include "classpropertiesdialog.h"
 #include "debug_utils.h"
+#include "dialog_utils.h"
 #include "docwindow.h"
 #include "listpopupmenu.h"
 #include "messagewidget.h"
@@ -26,23 +27,18 @@
 
 // kde includes
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <kinputdialog.h>
-#endif
 
 // qt includes
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
 #include <QPointer>
 #include <QPainter>
 #include <QValidator>
+#include <QXmlStreamWriter>
 
-#define O_MARGIN 5
-#define O_WIDTH 40
-#define A_WIDTH 20
+#define O_MARGIN  5
+#define O_WIDTH  40
+#define A_WIDTH  20
 #define A_HEIGHT 40
-#define A_MARGIN 5
+#define A_MARGIN  5
 
 DEBUG_REGISTER_DISABLED(ObjectWidget)
 
@@ -65,7 +61,7 @@ ObjectWidget::ObjectWidget(UMLScene * scene, UMLObject *o)
     m_showDestruction(false),
     m_isOnDestructionBox(false)
 {
-    if (m_scene && (m_scene->type() == Uml::DiagramType::Sequence)) {
+    if (m_scene && m_scene->isSequenceDiagram()) {
         m_pLine = new SeqLineWidget( m_scene, this );
         m_pLine->setStartPoint(x() + width() / 2, y() + height());
     } else {
@@ -89,7 +85,7 @@ ObjectWidget::~ObjectWidget()
 void ObjectWidget::setMultipleInstance(bool multiple)
 {
     //make sure only calling this in relation to an object on a collab. diagram
-    if (m_scene && (m_scene->type() == Uml::DiagramType::Collaboration)) {
+    if (m_scene && m_scene->isCollaborationDiagram()) {
         m_multipleInstance = multiple;
         updateGeometry();
         update();
@@ -106,6 +102,19 @@ bool ObjectWidget::multipleInstance() const
     return m_multipleInstance;
 }
 
+void ObjectWidget::setSelected(bool state)
+{
+    UMLWidget::setSelected(state);
+    if (m_pLine) {
+        QPen pen = m_pLine->pen();
+        int lineWidth = (int)UMLWidget::lineWidth();
+        if (state)
+            lineWidth = lineWidth ? lineWidth * 2 : 2;
+        pen.setWidth(lineWidth);
+        m_pLine->setPen(pen);
+    }
+}
+
 /**
  * Overridden from UMLWidget.
  * Moves the widget to a new position using the difference between the
@@ -135,7 +144,7 @@ void ObjectWidget::moveWidgetBy(qreal diffX, qreal diffY)
 void ObjectWidget::constrainMovementForAllWidgets(qreal &diffX, qreal &diffY)
 {
     Q_UNUSED(diffX);
-    if (m_scene && (m_scene->type() == Uml::DiagramType::Sequence)) {
+    if (m_scene && m_scene->isSequenceDiagram()) {
         diffY = 0;
     }
 }
@@ -165,36 +174,6 @@ void ObjectWidget::slotMenuSelection(QAction* action)
 {
     ListPopupMenu::MenuType sel = ListPopupMenu::typeFromAction(action);
     switch(sel) {
-    case ListPopupMenu::mt_Rename_Object:
-        {
-            bool ok;
-            QRegExpValidator* validator = new QRegExpValidator(QRegExp(QLatin1String(".*")), 0);
-#if QT_VERSION >= 0x050000
-            QString name = QInputDialog::getText(m_scene->activeView(),
-                                                 i18n("Rename Object"),
-                                                 i18n("Enter object name:"),
-                                                 QLineEdit::Normal,
-                                                 m_instanceName,
-                                                 &ok);
-#else
-            QString name = KInputDialog::getText
-                   (i18n("Rename Object"),
-                    i18n("Enter object name:"),
-                    m_instanceName,
-                    &ok,
-                    m_scene->activeView(),
-                    validator);
-#endif
-            if (ok) {
-                m_instanceName = name;
-                updateGeometry();
-                moveEvent(0);
-                update();
-                UMLApp::app()->document()->setModified(true);
-            }
-            delete validator;
-            break;
-        }
     case ListPopupMenu::mt_Properties:
         showPropertiesDialog();
         updateGeometry();
@@ -403,16 +382,19 @@ void ObjectWidget::cleanup()
 /**
  * Show a properties dialog for an ObjectWidget.
  */
-void ObjectWidget::showPropertiesDialog()
+bool ObjectWidget::showPropertiesDialog()
 {
+    bool result = false;
     UMLApp::app()->docWindow()->updateDocumentation(false);
     QPointer<ClassPropertiesDialog> dlg = new ClassPropertiesDialog((QWidget*)UMLApp::app(), this);
     if (dlg->exec()) {
         UMLApp::app()->docWindow()->showDocumentation(this, true);
         UMLApp::app()->document()->setModified(true);
+        result = true;
     }
     dlg->close();
     delete dlg;
+    return result;
 }
 
 /**
@@ -642,6 +624,18 @@ bool ObjectWidget::messageOverlap(qreal y, MessageWidget* messageWidget)
     return false;
 }
 
+/**
+ * Overridden from UMLWidget
+ * Set color of object widget and sequence line on sequence diagrams.
+ */
+void ObjectWidget::setLineColorCmd(const QColor &color)
+{
+    UMLWidget::setLineColorCmd(color);
+    if (m_pLine) {
+        m_pLine->setLineColorCmd(color);
+    }
+}
+
 /**
  * Return the SeqLineWidget.
  * Returns a non NULL pointer if this ObjectWidget is part of a
@@ -681,22 +675,22 @@ void ObjectWidget::resizeWidget(qreal newW, qreal newH)
 /**
  * Saves to the "objectwidget" XMI element.
  */
-void ObjectWidget::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+void ObjectWidget::saveToXMI1(QXmlStreamWriter& writer)
 {
-    QDomElement objectElement = qDoc.createElement(QLatin1String("objectwidget"));
-    UMLWidget::saveToXMI(qDoc, objectElement);
-    objectElement.setAttribute(QLatin1String("drawasactor"), m_drawAsActor);
-    objectElement.setAttribute(QLatin1String("multipleinstance"), m_multipleInstance);
-    objectElement.setAttribute(QLatin1String("decon"), m_showDestruction);
-    qElement.appendChild(objectElement);
+    writer.writeStartElement(QLatin1String("objectwidget"));
+    UMLWidget::saveToXMI1(writer);
+    writer.writeAttribute(QLatin1String("drawasactor"), QString::number(m_drawAsActor));
+    writer.writeAttribute(QLatin1String("multipleinstance"), QString::number(m_multipleInstance));
+    writer.writeAttribute(QLatin1String("decon"), QString::number(m_showDestruction));
+    writer.writeEndElement();
 }
 
 /**
  * Loads from a "objectwidget" XMI element.
  */
-bool ObjectWidget::loadFromXMI(QDomElement& qElement)
+bool ObjectWidget::loadFromXMI1(QDomElement& qElement)
 {
-    if(!UMLWidget::loadFromXMI(qElement))
+    if(!UMLWidget::loadFromXMI1(qElement))
         return false;
     QString draw = qElement.attribute(QLatin1String("drawasactor"), QLatin1String("0"));
     QString multi = qElement.attribute(QLatin1String("multipleinstance"), QLatin1String("0"));
