@@ -44,7 +44,7 @@ public:
     bool activate(IDChangeLog* Log = 0);
     void resolveObjectWidget(IDChangeLog* log);
 
-    virtual void saveToXMI1(QDomDocument& qDoc, QDomElement& qElement);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
     virtual bool loadFromXMI1(QDomElement& qElement);
 
     ObjectWidget *objectWidget() const;
