@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
+ *   copyright (C) 2002-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
 ***************************************************************************/
 
@@ -33,7 +33,7 @@
  *
  * @short  A graphical version of a UML State.
  * @author Paul Hensgen <phensgen@techie.com>
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class StateWidget : public UMLWidget
 {
@@ -51,10 +51,11 @@ public:
         Junction,        // Pseudostate
         DeepHistory,     // Pseudostate
         ShallowHistory,  // Pseudostate
-        Choice           // Pseudostate
+        Choice,          // Pseudostate
         //Terminate        // Pseudostate
         //EntryPoint       // Pseudostate
         //ExitPoint        // Pseudostate
+        Combined         // Pseudostate
     };
 
     explicit StateWidget(UMLScene * scene, StateType stateType = Normal, Uml::ID::Type id = Uml::ID::None);
@@ -79,12 +80,17 @@ public:
     virtual bool showPropertiesDialog();
 
     virtual bool loadFromXMI1(QDomElement & qElement);
-    virtual void saveToXMI1(QDomDocument & qDoc, QDomElement & qElement);
+    virtual void saveToXMI1(QXmlStreamWriter& writer);
 
 protected:
     QSizeF minimumSize() const;
     QSizeF maximumSize();
     void setAspectRatioMode();
+    virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
+    virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
+    virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
+    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
+    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
 
 public Q_SLOTS:
     virtual void slotMenuSelection(QAction* action);
@@ -93,7 +99,7 @@ private:
     StateType   m_stateType;   ///< Type of state.
     bool m_drawVertical;   ///< whether to draw the fork/join horizontally or vertically
     QStringList m_Activities;  ///< List of activities for the state.
-
+    QSizeF m_size;       ///< widget size used by combined state
 };
 
 #endif
