@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2014                                               *
+ *   copyright (C) 2004-2021                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -20,6 +20,7 @@
 #include "umlobject.h"
 #include "umlscene.h"
 #include "widgetbasepopupmenu.h"
+#include "uniqueid.h"
 
 #if QT_VERSION < 0x050000
 #include <kcolordialog.h>
@@ -33,6 +34,35 @@
 #include <QFontDialog>
 #endif
 #include <QPointer>
+#include <QXmlStreamWriter>
+
+static unsigned eventCnt = 0;
+
+void QGraphicsObjectWrapper::setSelected(bool state)
+{
+    if (!m_calledFromItemChange)
+        QGraphicsObject::setSelected(state);
+    QString info;
+    WidgetBase *wb = dynamic_cast<WidgetBase*>(this);
+    if (wb)
+        info = wb->name();
+    if (info.isEmpty()) {
+        DEBUG(DBG_SRC) << ++eventCnt << " new state=" << state << ", fromItemChange=" << m_calledFromItemChange << " " << this;
+    } else {
+        DEBUG(DBG_SRC) << ++eventCnt << " new state=" << state << ", fromItemChange=" << m_calledFromItemChange << " " << info;
+    }
+    m_calledFromItemChange = false;
+}
+
+QVariant QGraphicsObjectWrapper::itemChange(GraphicsItemChange change, const QVariant &value)
+{
+    if (change == ItemSelectedChange && scene()) {
+        bool state = value.toBool();
+        m_calledFromItemChange = true;
+        setSelected(state);
+    }
+    return QGraphicsItem::itemChange(change, value);
+}
 
 /**
  * Creates a WidgetBase object.
@@ -41,11 +71,13 @@
  * @param type    The WidgetType to construct.  This must be set to the appropriate
  *                value by the constructors of inheriting classes.
  */
-WidgetBase::WidgetBase(UMLScene *scene, WidgetType type)
-  : QGraphicsObject(),
+WidgetBase::WidgetBase(UMLScene *scene, WidgetType type, Uml::ID::Type id)
+  : QGraphicsObjectWrapper(),
     m_baseType(type),
     m_scene(scene),
     m_umlObject(0),
+    m_nId(id == Uml::ID::None ? UniqueID::gen() : id),
+    m_nLocalID(UniqueID::gen()),
     m_textColor(QColor("black")),
     m_fillColor(QColor("yellow")),
     m_brush(m_fillColor),
@@ -60,14 +92,14 @@ WidgetBase::WidgetBase(UMLScene *scene, WidgetType type)
     m_changesShape(false)
 {
     Q_ASSERT(m_baseType > wt_Min && m_baseType < wt_Max);
+    setFlags(ItemIsSelectable);
+    //setFlags(ItemIsSelectable | ItemIsMovable |ItemSendsGeometryChanges);
+
     // Note: no virtual methods from derived classes available,
     // this operation need to be finished in derived class constructor.
     setLineColor(QColor("black"));
     setSelected(false);
 
-    // TODO 310283
-    setFlags(ItemIsSelectable);
-    //setFlags(ItemIsSelectable | ItemIsMovable |ItemSendsGeometryChanges);
     if (m_scene) {
         m_usesDiagramLineColor = true;
         m_usesDiagramLineWidth  = true;
@@ -116,6 +148,15 @@ QLatin1String WidgetBase::baseTypeStr() const
     return QLatin1String(ENUM_NAME(WidgetBase, WidgetType, m_baseType));
 }
 
+/**
+ * @return The type as string without 'wt_' prefix.
+ */
+QString WidgetBase::baseTypeStrWithoutPrefix() const
+{
+    QString rawType = baseTypeStr();
+    return rawType.remove(QLatin1String("wt_"));
+}
+
 /*
  * Sets the state of whether the widget is selected.
  *
@@ -123,7 +164,7 @@ QLatin1String WidgetBase::baseTypeStr() const
  */
 void WidgetBase::setSelected(bool select)
 {
-    QGraphicsObject::setSelected(select);
+    QGraphicsObjectWrapper::setSelected(select);
 }
 
 /**
@@ -189,6 +230,49 @@ Uml::ID::Type WidgetBase::id() const
     return m_nId;
 }
 
+/**
+ * Sets the local id of the object.
+ *
+ * @param id   The local id of the object.
+ */
+void WidgetBase::setLocalID(Uml::ID::Type id)
+{
+    m_nLocalID = id;
+}
+
+/**
+ * Returns the local ID for this object.  This ID is used so that
+ * many objects of the same @ref UMLObject instance can be on the
+ * same diagram.
+ *
+ * @return  The local ID.
+ */
+Uml::ID::Type WidgetBase::localID() const
+{
+    return m_nLocalID;
+}
+
+/**
+ * Returns the widget with the given ID.
+ * The default implementation tests the following IDs:
+ * - m_nLocalID
+ * - if m_umlObject is non NULL: m_umlObject->id()
+ * - m_nID
+ * Composite widgets override this function to test further owned widgets.
+ *
+ * @param id  The ID to test this widget against.
+ * @return  'this' if id is either of m_nLocalID, m_umlObject->id(), or m_nId;
+ *           else NULL.
+ */
+UMLWidget* WidgetBase::widgetWithID(Uml::ID::Type id)
+{
+    if (id == m_nLocalID ||
+            (m_umlObject != nullptr && id == m_umlObject->id()) ||
+            id == m_nId)
+        return this->asUMLWidget();
+    return nullptr;
+}
+
 /**
  * Used by some child classes to get documentation.
  *
@@ -465,7 +549,7 @@ void WidgetBase::setUsesDiagramLineWidth(bool state)
 }
 
 /**
- * Returns the font used for diaplaying any text.
+ * Returns the font used for displaying any text.
  * @return the font
  */
 QFont WidgetBase::font() const
@@ -519,7 +603,7 @@ void WidgetBase::setChangesShape(bool state)
 
 /**
  * A virtual method for the widget to display a property dialog box.
- * Subclasses should reimplment this appropriately.
+ * Subclasses should reimplement this appropriately.
  * In case the user cancels the dialog or there are some requirements
  * not fulfilled the method returns false; true otherwise.
  *
@@ -534,49 +618,113 @@ bool WidgetBase::showPropertiesDialog()
 
 /**
  * A virtual method to save the properties of this widget into a
- * QDomElement i.e xml.
+ * QXmlStreamWriter i.e. XML.
  *
  * Subclasses should first create a new dedicated element as the child
  * of \a qElement parameter passed.  Then this base method should be
  * called to save basic widget properties.
  *
- * @param qDoc A QDomDocument object representing the xml document.
- * @param qElement A QDomElement representing xml element data.
+ * @param writer The QXmlStreamWriter to write to.
  */
-void WidgetBase::saveToXMI1(QDomDocument& qDoc, QDomElement& qElement)
+void WidgetBase::saveToXMI1(QXmlStreamWriter& writer)
  {
-    Q_UNUSED(qDoc)
+    writer.writeAttribute(QLatin1String("xmi.id"), Uml::ID::toString(id()));
+    // Unique identifier for widget (todo: id() should be unique, new attribute
+    // should indicate the UMLObject's ID it belongs to)
+    writer.writeAttribute(QLatin1String("localid"), Uml::ID::toString(m_nLocalID));
 
-    qElement.setAttribute(QLatin1String("textcolor"), m_usesDiagramTextColor ? QLatin1String("none")
+    writer.writeAttribute(QLatin1String("textcolor"), m_usesDiagramTextColor ? QLatin1String("none")
                                                                              : m_textColor.name());
     if (m_usesDiagramLineColor) {
-        qElement.setAttribute(QLatin1String("linecolor"), QLatin1String("none"));
+        writer.writeAttribute(QLatin1String("linecolor"), QLatin1String("none"));
     } else {
-        qElement.setAttribute(QLatin1String("linecolor"), m_lineColor.name());
+        writer.writeAttribute(QLatin1String("linecolor"), m_lineColor.name());
     }
     if (m_usesDiagramLineWidth) {
-        qElement.setAttribute(QLatin1String("linewidth"), QLatin1String("none"));
+        writer.writeAttribute(QLatin1String("linewidth"), QLatin1String("none"));
     } else {
-        qElement.setAttribute(QLatin1String("linewidth"), m_lineWidth);
+        writer.writeAttribute(QLatin1String("linewidth"), QString::number(m_lineWidth));
     }
-    qElement.setAttribute(QLatin1String("usefillcolor"), m_useFillColor);
+    writer.writeAttribute(QLatin1String("usefillcolor"), QString::number(m_useFillColor));
     // for consistency the following attributes now use american spelling for "color"
-    qElement.setAttribute(QLatin1String("usesdiagramfillcolor"), m_usesDiagramFillColor);
-    qElement.setAttribute(QLatin1String("usesdiagramusefillcolor"), m_usesDiagramUseFillColor);
+    writer.writeAttribute(QLatin1String("usesdiagramfillcolor"), QString::number(m_usesDiagramFillColor));
+    writer.writeAttribute(QLatin1String("usesdiagramusefillcolor"), QString::number(m_usesDiagramUseFillColor));
     if (m_usesDiagramFillColor) {
-        qElement.setAttribute(QLatin1String("fillcolor"), QLatin1String("none"));
+        writer.writeAttribute(QLatin1String("fillcolor"), QLatin1String("none"));
     } else {
-        qElement.setAttribute(QLatin1String("fillcolor"), m_fillColor.name());
+        writer.writeAttribute(QLatin1String("fillcolor"), m_fillColor.name());
     }
-    qElement.setAttribute(QLatin1String("font"), m_font.toString());
-    qElement.setAttribute(QLatin1String("autoresize"), m_autoResize ? 1 : 0);
+    writer.writeAttribute(QLatin1String("font"), m_font.toString());
+    writer.writeAttribute(QLatin1String("autoresize"), QString::number(m_autoResize ? 1 : 0));
+}
+
+
+/**
+ * Returns whether the widget type has an associated UMLObject
+ */
+bool WidgetBase::widgetHasUMLObject(WidgetBase::WidgetType type)
+{
+    if (type == WidgetBase::wt_Actor         ||
+            type == WidgetBase::wt_UseCase   ||
+            type == WidgetBase::wt_Class     ||
+            type == WidgetBase::wt_Interface ||
+            type == WidgetBase::wt_Enum      ||
+            type == WidgetBase::wt_Datatype  ||
+            type == WidgetBase::wt_Package   ||
+            type == WidgetBase::wt_Component ||
+            type == WidgetBase::wt_Port ||
+            type == WidgetBase::wt_Node      ||
+            type == WidgetBase::wt_Artifact  ||
+            type == WidgetBase::wt_Object) {
+        return true;
+    } else {
+        return false;
+    }
+}
+
+/**
+ * Activate the object after deserializing it from XMI
+ *
+ * @param ChangeLog
+ * @return  true for success
+ */
+bool WidgetBase::activate(IDChangeLog* changeLog)
+{
+    Q_UNUSED(changeLog);
+
+    if (widgetHasUMLObject(baseType()) && m_umlObject == nullptr) {
+        m_umlObject =  UMLApp::app()->document()->findObjectById(m_nId);
+        if (m_umlObject == nullptr) {
+            uError() << "cannot find UMLObject with id=" << Uml::ID::toString(m_nId);
+            return false;
+        }
+    }
+    return true;
+}
+
+/**
+ * Adds an already created association to the list of
+ * associations that include this UMLWidget
+ */
+void WidgetBase::addAssoc(AssociationWidget *pAssoc)
+{
+    Q_UNUSED(pAssoc);
+}
+
+/**
+ * Removes an already created association from the list of
+ * associations that include this UMLWidget
+ */
+void WidgetBase::removeAssoc(AssociationWidget *pAssoc)
+{
+    Q_UNUSED(pAssoc);
 }
 
 /**
  * A virtual method to load the properties of this widget from a
  * QDomElement into this widget.
  *
- * Subclasses should reimplement this to load addtional properties
+ * Subclasses should reimplement this to load additional properties
  * required, calling this base method to load the basic properties of
  * the widget.
  *
@@ -586,6 +734,14 @@ void WidgetBase::saveToXMI1(QDomDocument& qDoc, QDomElement& qElement)
  */
 bool WidgetBase::loadFromXMI1(QDomElement& qElement)
 {
+    QString id = qElement.attribute(QLatin1String("xmi.id"), QLatin1String("-1"));
+    m_nId = Uml::ID::fromString(id);
+
+    QString localid = qElement.attribute(QLatin1String("localid"), QLatin1String("0"));
+    if (localid != QLatin1String("0")) {
+        m_nLocalID = Uml::ID::fromString(localid);
+    }
+
     // first load from "linecolour" and then overwrite with the "linecolor"
     // attribute if that one is present. The "linecolour" name was a "typo" in
     // earlier versions of Umbrello
@@ -661,6 +817,7 @@ WidgetBase& WidgetBase::operator=(const WidgetBase& other)
     m_Doc = other.m_Doc;
     m_Text = other.m_Text;
     m_nId = other.m_nId;
+    m_nLocalID = other.m_nLocalID;
     m_textColor = other.m_textColor;
     setLineColor(other.lineColor());
     m_fillColor = other.m_fillColor;
@@ -938,6 +1095,8 @@ void WidgetBase::slotMenuSelection(QAction *trigger)
 
     case ListPopupMenu::mt_Show_Stereotypes_Selection:
     case ListPopupMenu::mt_Hide_Stereotypes_Selection:
+        // Bug73847 - ClassifierWidget::ShowStereotype boolean value is DEPRECATED
+        //     TODO - handle this differently, then delete ClassifierWidget::ShowStereotype
         umlScene()->selectionSetVisualProperty(
             ClassifierWidget::ShowStereotype, sel != ListPopupMenu::mt_Hide_Stereotypes_Selection
         );
